==> aws-spa-3.3.0.tgz: package/lib/cloudfront/index.spec.js <==
"use strict";

var _ = require(".");

var _awsServices = require("../aws-services");

var _lambda = require("../lambda");

var _testHelper = require("../test-helper");

describe("cloudfront", () => {
  describe("findDeployedCloudfrontDistribution", () => {
    const listDistributionMock = jest.spyOn(_awsServices.cloudfront, "listDistributions");
    const listTagsForResourceMock = jest.spyOn(_awsServices.cloudfront, "listTagsForResource");
    const waitForMock = jest.spyOn(_awsServices.cloudfront, "waitFor");
    afterEach(() => {
      listDistributionMock.mockReset();
      listTagsForResourceMock.mockReset();
      waitForMock.mockReset();
    });
    it("should return the distribution even if on page 2", async () => {
      listDistributionMock.mockReturnValueOnce((0, _testHelper.awsResolve)({
        DistributionList: {
          NextMarker: "xxx",
          Items: [{
            Id: "GOODBYE",
            Aliases: {
              Items: ["goodbye.example.com"]
            }
          }]
        }
      })).mockReturnValueOnce((0, _testHelper.awsResolve)({
        DistributionList: {
          Items: [{
            Id: "HELLO",
            Status: "Deployed",
            Aliases: {
              Items: ["hello.example.com"]
            }
          }]
        }
      }));
      listTagsForResourceMock.mockReturnValue((0, _testHelper.awsResolve)({
        Tags: {
          Items: [_.identifyingTag]
        }
      }));
      const distribution = await (0, _.findDeployedCloudfrontDistribution)("hello.example.com");
      expect(distribution).toBeDefined();
      expect(distribution.Id).toEqual("HELLO");
    });
    it("should wait for distribution if distribution is not deployed", async () => {
      listDistributionMock.mockReturnValue((0, _testHelper.awsResolve)({
        DistributionList: {
          Items: [{
            Id: "HELLO",
            Status: "In Progress",
            Aliases: {
              Items: ["hello.example.com"]
            }
          }]
        }
      }));
      listTagsForResourceMock.mockReturnValue((0, _testHelper.awsResolve)({
        Tags: {
          Items: [_.identifyingTag]
        }
      }));
      waitForMock.mockReturnValue((0, _testHelper.awsResolve)());
      await (0, _.findDeployedCloudfrontDistribution)("hello.example.com");
      expect(waitForMock).toHaveBeenCalledTimes(1);
    });
  });
  describe("invalidateCloudfrontCache", () => {
    const createInvalidationMock = jest.spyOn(_awsServices.cloudfront, "createInvalidation");
    const waitForMock = jest.spyOn(_awsServices.cloudfront, "waitFor");
    afterEach(() => {
      createInvalidationMock.mockReset();
      waitForMock.mockReset();
    });
    it("should invalidate the specified path", async () => {
      createInvalidationMock.mockReturnValue((0, _testHelper.awsResolve)({
        Invalidation: {}
      }));
      await (0, _.invalidateCloudfrontCache)("some-distribution-id", "index.html");
      expect(createInvalidationMock).toHaveBeenCalledTimes(1);
      const invalidationParams = createInvalidationMock.mock.calls[0][0];
      expect(invalidationParams.DistributionId).toEqual("some-distribution-id");
      expect(invalidationParams.InvalidationBatch.Paths.Items[0]).toEqual("index.html");
    });
    it("should invalidate the specified paths", async () => {
      createInvalidationMock.mockReturnValue((0, _testHelper.awsResolve)({
        Invalidation: {}
      }));
      await (0, _.invalidateCloudfrontCache)("some-distribution-id", "index.html, static/*");
      expect(createInvalidationMock).toHaveBeenCalledTimes(1);
      const invalidationParams = createInvalidationMock.mock.calls[0][0];
      expect(invalidationParams.DistributionId).toEqual("some-distribution-id");
      expect(invalidationParams.InvalidationBatch.Paths.Items).toEqual(["index.html", "static/*"]);
    });
    it("should wait for invalidate if wait flag is true", async () => {
      createInvalidationMock.mockReturnValue((0, _testHelper.awsResolve)({
        Invalidation: {}
      }));
      waitForMock.mockReturnValue((0, _testHelper.awsResolve)());
      await (0, _.invalidateCloudfrontCache)("some-distribution-id", "index.html", true);
      expect(waitForMock).toHaveBeenCalledTimes(1);
      expect(waitForMock.mock.calls[0][0]).toEqual("invalidationCompleted");
    });
  });
  describe("invalidateCloudfrontCacheWithRetry", () => {
    const createInvalidationMock = jest.spyOn(_awsServices.cloudfront, "createInvalidation");
    const waitForMock = jest.spyOn(_awsServices.cloudfront, "waitFor");
    afterEach(() => {
      createInvalidationMock.mockReset();
      waitForMock.mockReset();
    });
    it("should retry once", async () => {
      createInvalidationMock.mockReturnValueOnce((0, _testHelper.awsReject)(1)).mockReturnValueOnce((0, _testHelper.awsResolve)({
        Invalidation: {}
      }));
      await (0, _.invalidateCloudfrontCacheWithRetry)("some-distribution-id", "index.html, static/*");
      expect(createInvalidationMock).toHaveBeenCalledTimes(2);
    });
    it("should retry 5 times at most", async () => {
      createInvalidationMock.mockReturnValueOnce((0, _testHelper.awsReject)(1)).mockReturnValueOnce((0, _testHelper.awsReject)(1)).mockReturnValueOnce((0, _testHelper.awsReject)(1)).mockReturnValueOnce((0, _testHelper.awsReject)(1)).mockReturnValueOnce((0, _testHelper.awsReject)(1)).mockReturnValueOnce((0, _testHelper.awsReject)(1)).mockReturnValueOnce((0, _testHelper.awsReject)(1)).mockReturnValueOnce((0, _testHelper.awsResolve)({
        Invalidation: {}
      }));

      try {
        await (0, _.invalidateCloudfrontCacheWithRetry)("some-distribution-id", "index.html, static/*");
      } catch (error) {
        expect(error).toBeDefined();
      }

      expect(createInvalidationMock).toHaveBeenCalledTimes(5);
    });
  });
  describe("createCloudFrontDistribution", () => {
    const createDistributionMock = jest.spyOn(_awsServices.cloudfront, "createDistribution");
    const waitForMock = jest.spyOn(_awsServices.cloudfront, "waitFor");
    const tagResourceMock = jest.spyOn(_awsServices.cloudfront, "tagResource");
    afterEach(() => {
      createDistributionMock.mockReset();
      waitForMock.mockReset();
      tagResourceMock.mockReset();
    });
    it("should create a distribution and wait for it to be available", async () => {
      const distribution = {
        Id: "distribution-id"
      };
      createDistributionMock.mockReturnValue((0, _testHelper.awsResolve)({
        Distribution: distribution
      }));
      tagResourceMock.mockReturnValue((0, _testHelper.awsResolve)());
      waitForMock.mockReturnValue((0, _testHelper.awsResolve)());
      const result = await (0, _.createCloudFrontDistribution)("hello.lalilo.com", "arn:certificate");
      expect(result).toBe(distribution);
      expect(tagResourceMock).toHaveBeenCalledTimes(1);
      expect(createDistributionMock).toHaveBeenCalledTimes(1);
      const distributionParam = createDistributionMock.mock.calls[0][0];
      const distributionConfig = distributionParam.DistributionConfig;
      expect(distributionConfig.Origins.Items[0].DomainName).toEqual("hello.lalilo.com.s3-website.eu-west-3.amazonaws.com");
      expect(distributionConfig.DefaultCacheBehavior.ViewerProtocolPolicy).toEqual("redirect-to-https");
      expect(distributionConfig.DefaultCacheBehavior.MinTTL).toEqual(0);
      expect(distributionConfig.DefaultCacheBehavior.Compress).toEqual(true);
      expect(distributionConfig.ViewerCertificate.ACMCertificateArn).toEqual("arn:certificate");
      expect(waitForMock).toHaveBeenCalledTimes(1);
      expect(waitForMock).toHaveBeenCalledWith("distributionDeployed", {
        Id: "distribution-id"
      });
    });
  });
  describe("setSimpleAuthBehavior", () => {
    const getDistributionConfig = jest.spyOn(_awsServices.cloudfront, "getDistributionConfig");
    const updateDistribution = jest.spyOn(_awsServices.cloudfront, "updateDistribution");
    beforeEach(() => {
      getDistributionConfig.mockReset();
      updateDistribution.mockReset();
    });
    it("should not update if there is no lambda association & no credentials", async () => {
      getDistributionConfig.mockReturnValueOnce((0, _testHelper.awsResolve)({
        DistributionConfig: {
          DefaultCacheBehavior: {
            LambdaFunctionAssociations: {
              Items: []
            }
          }
        },
        ETag: ""
      }));
      await (0, _.setSimpleAuthBehavior)("distribution-id", null);
      expect(updateDistribution).not.toHaveBeenCalled();
    });
    it("should remove lambda association if lambda is set but no credential is set", async () => {
      getDistributionConfig.mockReturnValueOnce((0, _testHelper.awsResolve)({
        DistributionConfig: {
          DefaultCacheBehavior: {
            LambdaFunctionAssociations: {
              Items: [{
                LambdaFunctionARN: `some-arn:${_lambda.lambdaPrefix}:1`
              }]
            }
          }
        },
        ETag: ""
      }));
      updateDistribution.mockReturnValueOnce((0, _testHelper.awsResolve)());
      await (0, _.setSimpleAuthBehavior)("distribution-id", null);
      expect(updateDistribution).toHaveBeenCalledTimes(1);
      expect(updateDistribution.mock.calls[0][0].DistributionConfig.DefaultCacheBehavior.LambdaFunctionAssociations.Items).toEqual([]);
    });
    it("should not update if there is a lambda association & credentials", async () => {
      getDistributionConfig.mockReturnValueOnce((0, _testHelper.awsResolve)({
        DistributionConfig: {
          DefaultCacheBehavior: {
            LambdaFunctionAssociations: {
              Items: [{
                LambdaFunctionARN: `some-arn:${_lambda.lambdaPrefix}:1`
              }]
            }
          }
        },
        ETag: ""
      }));
      await (0, _.setSimpleAuthBehavior)("distribution-id", `some-arn:${_lambda.lambdaPrefix}:1`);
      expect(updateDistribution).not.toHaveBeenCalled();
    });
    it("should add lambda association if lambda is not set set but credentials are set", async () => {
      getDistributionConfig.mockReturnValueOnce((0, _testHelper.awsResolve)({
        DistributionConfig: {
          DefaultCacheBehavior: {
            LambdaFunctionAssociations: {
              Items: []
            }
          }
        },
        ETag: ""
      }));
      updateDistribution.mockReturnValueOnce((0, _testHelper.awsResolve)());
      await (0, _.setSimpleAuthBehavior)("distribution-id", "some-arn:1");
      expect(updateDistribution).toHaveBeenCalledTimes(1);
      expect(updateDistribution.mock.calls[0][0].DistributionConfig.DefaultCacheBehavior.LambdaFunctionAssociations.Items).toEqual([{
        EventType: "viewer-request",
        IncludeBody: false,
        LambdaFunctionARN: "some-arn:1"
      }]);
    });
  });
  describe("getCacheInvalidations", () => {
    it.each([{
      input: "index.html",
      expectedOutput: "/index.html"
    }, {
      input: "/index.html",
      expectedOutput: "/index.html"
    }, {
      input: "index.html, hello.html",
      subFolder: undefined,
      expectedOutput: "/index.html,/hello.html"
    }, {
      input: "index.html",
      subFolder: "some-branch",
      expectedOutput: "/some-branch/index.html"
    }])("add missing slash", ({
      input,
      subFolder,
      expectedOutput
    }) => {
      expect((0, _.getCacheInvalidations)(input, subFolder)).toEqual(expectedOutput);
    });
  });
  describe("updateCloudFrontDistribution", () => {
    const getDistributionConfigMock = jest.spyOn(_awsServices.cloudfront, "getDistributionConfig");
    const updateDistribution = jest.spyOn(_awsServices.cloudfront, "updateDistribution");
    beforeEach(() => {
      getDistributionConfigMock.mockReset();
      updateDistribution.mockReset();
    });
    it.each([{
      shouldBlockBucketPublicAccess: true
    }, {
      shouldBlockBucketPublicAccess: false
    }])("should not update the distribution if the right origin is already associated", async ({
      shouldBlockBucketPublicAccess
    }) => {
      const domainName = "hello.lalilo.com";
      const originId = shouldBlockBucketPublicAccess ? (0, _awsServices.getS3DomainNameForBlockedBucket)(domainName) : (0, _awsServices.getS3DomainName)(domainName);
      const distribution = {
        Id: "distribution-id",
        Origins: {
          Items: [{
            Id: originId
          }]
        },
        DefaultCacheBehavior: {
          TargetOriginId: originId
        }
      };
      getDistributionConfigMock.mockReturnValue((0, _testHelper.awsResolve)({
        DistributionConfig: distribution
      }));
      await (0, _.updateCloudFrontDistribution)(distribution.Id, domainName, shouldBlockBucketPublicAccess, undefined);
      expect(updateDistribution).not.toHaveBeenCalled();
    });
    it("should update the distribution with an OAC when shouldBlockBucketPublicAccess and oac is given", async () => {
      const shouldBlockBucketPublicAccess = true;
      const domainName = "hello.lalilo.com";
      const originIdForPrivateBucket = (0, _awsServices.getS3DomainNameForBlockedBucket)(domainName);
      const oac = {
        originAccessControl: {
          Id: "oac-id"
        },
        ETag: "etag"
      };
      const distribution = {
        Id: "distribution-id",
        Origins: {
          Items: [{
            Id: (0, _awsServices.getS3DomainName)(domainName)
          }]
        },
        DefaultCacheBehavior: {
          TargetOriginId: (0, _awsServices.getS3DomainName)(domainName)
        }
      };
      getDistributionConfigMock.mockReturnValue((0, _testHelper.awsResolve)({
        DistributionConfig: distribution
      }));
      updateDistribution.mockReturnValueOnce((0, _testHelper.awsResolve)());
      await (0, _.updateCloudFrontDistribution)(distribution.Id, domainName, shouldBlockBucketPublicAccess, oac);
      expect(updateDistribution).toHaveBeenCalled();
      expect(updateDistribution).toHaveBeenCalledWith(expect.objectContaining({
        DistributionConfig: expect.objectContaining({
          Origins: expect.objectContaining({
            Items: [expect.objectContaining({
              Id: originIdForPrivateBucket,
              DomainName: originIdForPrivateBucket,
              OriginAccessControlId: oac.originAccessControl.Id,
              S3OriginConfig: {
                OriginAccessIdentity: ""
              }
            })]
          }),
          DefaultCacheBehavior: expect.objectContaining({
            TargetOriginId: originIdForPrivateBucket
          })
        })
      }));
    });
  });
});

==> aws-spa-3.3.1.tgz: package/lib/cloudfront/index.spec.js <==
"use strict";

var _ = require(".");

var _awsServices = require("../aws-services");

var _lambda = require("../lambda");

var _testHelper = require("../test-helper");

describe("cloudfront", () => {
  describe("findDeployedCloudfrontDistribution", () => {
    const listDistributionMock = jest.spyOn(_awsServices.cloudfront, "listDistributions");
    const listTagsForResourceMock = jest.spyOn(_awsServices.cloudfront, "listTagsForResource");
    const waitForMock = jest.spyOn(_awsServices.cloudfront, "waitFor");
    afterEach(() => {
      listDistributionMock.mockReset();
      listTagsForResourceMock.mockReset();
      waitForMock.mockReset();
    });
    it("should return the distribution even if on page 2", async () => {
      listDistributionMock.mockReturnValueOnce((0, _testHelper.awsResolve)({
        DistributionList: {
          NextMarker: "xxx",
          Items: [{
            Id: "GOODBYE",
            Aliases: {
              Items: ["goodbye.example.com"]
            }
          }]
        }
      })).mockReturnValueOnce((0, _testHelper.awsResolve)({
        DistributionList: {
          Items: [{
            Id: "HELLO",
            Status: "Deployed",
            Aliases: {
              Items: ["hello.example.com"]
            }
          }]
        }
      }));
      listTagsForResourceMock.mockReturnValue((0, _testHelper.awsResolve)({
        Tags: {
          Items: [_.identifyingTag]
        }
      }));
      const distribution = await (0, _.findDeployedCloudfrontDistribution)("hello.example.com");
      expect(distribution).toBeDefined();
      expect(distribution.Id).toEqual("HELLO");
    });
    it("should wait for distribution if distribution is not deployed", async () => {
      listDistributionMock.mockReturnValue((0, _testHelper.awsResolve)({
        DistributionList: {
          Items: [{
            Id: "HELLO",
            Status: "In Progress",
            Aliases: {
              Items: ["hello.example.com"]
            }
          }]
        }
      }));
      listTagsForResourceMock.mockReturnValue((0, _testHelper.awsResolve)({
        Tags: {
          Items: [_.identifyingTag]
        }
      }));
      waitForMock.mockReturnValue((0, _testHelper.awsResolve)());
      await (0, _.findDeployedCloudfrontDistribution)("hello.example.com");
      expect(waitForMock).toHaveBeenCalledTimes(1);
    });
  });
  describe("invalidateCloudfrontCache", () => {
    const createInvalidationMock = jest.spyOn(_awsServices.cloudfront, "createInvalidation");
    const waitForMock = jest.spyOn(_awsServices.cloudfront, "waitFor");
    afterEach(() => {
      createInvalidationMock.mockReset();
      waitForMock.mockReset();
    });
    it("should invalidate the specified path", async () => {
      createInvalidationMock.mockReturnValue((0, _testHelper.awsResolve)({
        Invalidation: {}
      }));
      await (0, _.invalidateCloudfrontCache)("some-distribution-id", "index.html");
      expect(createInvalidationMock).toHaveBeenCalledTimes(1);
      const invalidationParams = createInvalidationMock.mock.calls[0][0];
      expect(invalidationParams.DistributionId).toEqual("some-distribution-id");
      expect(invalidationParams.InvalidationBatch.Paths.Items[0]).toEqual("index.html");
    });
    it("should invalidate the specified paths", async () => {
      createInvalidationMock.mockReturnValue((0, _testHelper.awsResolve)({
        Invalidation: {}
      }));
      await (0, _.invalidateCloudfrontCache)("some-distribution-id", "index.html, static/*");
      expect(createInvalidationMock).toHaveBeenCalledTimes(1);
      const invalidationParams = createInvalidationMock.mock.calls[0][0];
      expect(invalidationParams.DistributionId).toEqual("some-distribution-id");
      expect(invalidationParams.InvalidationBatch.Paths.Items).toEqual(["index.html", "static/*"]);
    });
    it("should wait for invalidate if wait flag is true", async () => {
      createInvalidationMock.mockReturnValue((0, _testHelper.awsResolve)({
        Invalidation: {}
      }));
      waitForMock.mockReturnValue((0, _testHelper.awsResolve)());
      await (0, _.invalidateCloudfrontCache)("some-distribution-id", "index.html", true);
      expect(waitForMock).toHaveBeenCalledTimes(1);
      expect(waitForMock.mock.calls[0][0]).toEqual("invalidationCompleted");
    });
  });
  describe("invalidateCloudfrontCacheWithRetry", () => {
    const createInvalidationMock = jest.spyOn(_awsServices.cloudfront, "createInvalidation");
    const waitForMock = jest.spyOn(_awsServices.cloudfront, "waitFor");
    afterEach(() => {
      createInvalidationMock.mockReset();
      waitForMock.mockReset();
    });
    it("should retry once", async () => {
      createInvalidationMock.mockReturnValueOnce((0, _testHelper.awsReject)(1)).mockReturnValueOnce((0, _testHelper.awsResolve)({
        Invalidation: {}
      }));
      await (0, _.invalidateCloudfrontCacheWithRetry)("some-distribution-id", "index.html, static/*");
      expect(createInvalidationMock).toHaveBeenCalledTimes(2);
    });
    it("should retry 5 times at most", async () => {
      createInvalidationMock.mockReturnValueOnce((0, _testHelper.awsReject)(1)).mockReturnValueOnce((0, _testHelper.awsReject)(1)).mockReturnValueOnce((0, _testHelper.awsReject)(1)).mockReturnValueOnce((0, _testHelper.awsReject)(1)).mockReturnValueOnce((0, _testHelper.awsReject)(1)).mockReturnValueOnce((0, _testHelper.awsReject)(1)).mockReturnValueOnce((0, _testHelper.awsReject)(1)).mockReturnValueOnce((0, _testHelper.awsResolve)({
        Invalidation: {}
      }));

      try {
        await (0, _.invalidateCloudfrontCacheWithRetry)("some-distribution-id", "index.html, static/*");
      } catch (error) {
        expect(error).toBeDefined();
      }

      expect(createInvalidationMock).toHaveBeenCalledTimes(5);
    });
  });
  describe("createCloudFrontDistribution", () => {
    const createDistributionMock = jest.spyOn(_awsServices.cloudfront, "createDistribution");
    const waitForMock = jest.spyOn(_awsServices.cloudfront, "waitFor");
    const tagResourceMock = jest.spyOn(_awsServices.cloudfront, "tagResource");
    afterEach(() => {
      createDistributionMock.mockReset();
      waitForMock.mockReset();
      tagResourceMock.mockReset();
    });
    it("should create a distribution and wait for it to be available", async () => {
      const distribution = {
        Id: "distribution-id"
      };
      createDistributionMock.mockReturnValue((0, _testHelper.awsResolve)({
        Distribution: distribution
      }));
      tagResourceMock.mockReturnValue((0, _testHelper.awsResolve)());
      waitForMock.mockReturnValue((0, _testHelper.awsResolve)());
      const result = await (0, _.createCloudFrontDistribution)("hello.lalilo.com", "arn:certificate");
      expect(result).toBe(distribution);
      expect(tagResourceMock).toHaveBeenCalledTimes(1);
      expect(createDistributionMock).toHaveBeenCalledTimes(1);
      const distributionParam = createDistributionMock.mock.calls[0][0];
      const distributionConfig = distributionParam.DistributionConfig;
      expect(distributionConfig.Origins.Items[0].DomainName).toEqual("hello.lalilo.com.s3-website.eu-west-3.amazonaws.com");
      expect(distributionConfig.DefaultCacheBehavior.ViewerProtocolPolicy).toEqual("redirect-to-https");
      expect(distributionConfig.DefaultCacheBehavior.MinTTL).toEqual(0);
      expect(distributionConfig.DefaultCacheBehavior.Compress).toEqual(true);
      expect(distributionConfig.ViewerCertificate.ACMCertificateArn).toEqual("arn:certificate");
      expect(waitForMock).toHaveBeenCalledTimes(1);
      expect(waitForMock).toHaveBeenCalledWith("distributionDeployed", {
        Id: "distribution-id"
      });
    });
  });
  describe("setSimpleAuthBehavior", () => {
    const getDistributionConfig = jest.spyOn(_awsServices.cloudfront, "getDistributionConfig");
    const updateDistribution = jest.spyOn(_awsServices.cloudfront, "updateDistribution");
    beforeEach(() => {
      getDistributionConfig.mockReset();
      updateDistribution.mockReset();
    });
    it("should not update if there is no lambda association & no credentials", async () => {
      getDistributionConfig.mockReturnValueOnce((0, _testHelper.awsResolve)({
        DistributionConfig: {
          DefaultCacheBehavior: {
            LambdaFunctionAssociations: {
              Items: []
            }
          }
        },
        ETag: ""
      }));
      await (0, _.setSimpleAuthBehavior)("distribution-id", null);
      expect(updateDistribution).not.toHaveBeenCalled();
    });
    it("should remove lambda association if lambda is set but no credential is set", async () => {
      getDistributionConfig.mockReturnValueOnce((0, _testHelper.awsResolve)({
        DistributionConfig: {
          DefaultCacheBehavior: {
            LambdaFunctionAssociations: {
              Items: [{
                LambdaFunctionARN: `some-arn:${_lambda.lambdaPrefix}:1`
              }]
            }
          }
        },
        ETag: ""
      }));
      updateDistribution.mockReturnValueOnce((0, _testHelper.awsResolve)());
      await (0, _.setSimpleAuthBehavior)("distribution-id", null);
      expect(updateDistribution).toHaveBeenCalledTimes(1);
      expect(updateDistribution.mock.calls[0][0].DistributionConfig.DefaultCacheBehavior.LambdaFunctionAssociations.Items).toEqual([]);
    });
    it("should not update if there is a lambda association & credentials", async () => {
      getDistributionConfig.mockReturnValueOnce((0, _testHelper.awsResolve)({
        DistributionConfig: {
          DefaultCacheBehavior: {
            LambdaFunctionAssociations: {
              Items: [{
                LambdaFunctionARN: `some-arn:${_lambda.lambdaPrefix}:1`
              }]
            }
          }
        },
        ETag: ""
      }));
      await (0, _.setSimpleAuthBehavior)("distribution-id", `some-arn:${_lambda.lambdaPrefix}:1`);
      expect(updateDistribution).not.toHaveBeenCalled();
    });
    it("should add lambda association if lambda is not set set but credentials are set", async () => {
      getDistributionConfig.mockReturnValueOnce((0, _testHelper.awsResolve)({
        DistributionConfig: {
          DefaultCacheBehavior: {
            LambdaFunctionAssociations: {
              Items: []
            }
          }
        },
        ETag: ""
      }));
      updateDistribution.mockReturnValueOnce((0, _testHelper.awsResolve)());
      await (0, _.setSimpleAuthBehavior)("distribution-id", "some-arn:1");
      expect(updateDistribution).toHaveBeenCalledTimes(1);
      expect(updateDistribution.mock.calls[0][0].DistributionConfig.DefaultCacheBehavior.LambdaFunctionAssociations.Items).toEqual([{
        EventType: "viewer-request",
        IncludeBody: false,
        LambdaFunctionARN: "some-arn:1"
      }]);
    });
  });
  describe("getCacheInvalidations", () => {
    it.each([{
      input: "index.html",
      expectedOutput: "/index.html"
    }, {
      input: "/index.html",
      expectedOutput: "/index.html"
    }, {
      input: "index.html, hello.html",
      subFolder: undefined,
      expectedOutput: "/index.html,/hello.html"
    }, {
      input: "index.html",
      subFolder: "some-branch",
      expectedOutput: "/some-branch/index.html"
    }])("add missing slash", ({
      input,
      subFolder,
      expectedOutput
    }) => {
      expect((0, _.getCacheInvalidations)(input, subFolder)).toEqual(expectedOutput);
    });
  });
  describe("updateCloudFrontDistribution", () => {
    const getDistributionConfigMock = jest.spyOn(_awsServices.cloudfront, "getDistributionConfig");
    const updateDistribution = jest.spyOn(_awsServices.cloudfront, "updateDistribution");
    beforeEach(() => {
      getDistributionConfigMock.mockReset();
      updateDistribution.mockReset();
    });
    it.each([{
      shouldBlockBucketPublicAccess: true
    }, {
      shouldBlockBucketPublicAccess: false
    }])("should not update the distribution if the right origin is already associated", async ({
      shouldBlockBucketPublicAccess
    }) => {
      const domainName = "hello.lalilo.com";
      const originId = shouldBlockBucketPublicAccess ? (0, _awsServices.getS3DomainNameForBlockedBucket)(domainName) : (0, _awsServices.getS3DomainName)(domainName);
      const distribution = {
        Id: "distribution-id",
        Origins: {
          Items: [{
            Id: originId
          }]
        },
        DefaultCacheBehavior: {
          TargetOriginId: originId
        }
      };
      getDistributionConfigMock.mockReturnValue((0, _testHelper.awsResolve)({
        DistributionConfig: distribution
      }));
      await (0, _.updateCloudFrontDistribution)(distribution.Id, domainName, shouldBlockBucketPublicAccess, null);
      expect(updateDistribution).not.toHaveBeenCalled();
    });
    it("should update the distribution with an OAC when shouldBlockBucketPublicAccess and oac is given", async () => {
      const shouldBlockBucketPublicAccess = true;
      const domainName = "hello.lalilo.com";
      const originIdForPrivateBucket = (0, _awsServices.getS3DomainNameForBlockedBucket)(domainName);
      const oac = {
        originAccessControl: {
          Id: "oac-id"
        },
        ETag: "etag"
      };
      const distribution = {
        Id: "distribution-id",
        Origins: {
          Items: [{
            Id: (0, _awsServices.getS3DomainName)(domainName)
          }]
        },
        DefaultCacheBehavior: {
          TargetOriginId: (0, _awsServices.getS3DomainName)(domainName)
        }
      };
      getDistributionConfigMock.mockReturnValue((0, _testHelper.awsResolve)({
        DistributionConfig: distribution
      }));
      updateDistribution.mockReturnValueOnce((0, _testHelper.awsResolve)());
      await (0, _.updateCloudFrontDistribution)(distribution.Id, domainName, shouldBlockBucketPublicAccess, oac);
      expect(updateDistribution).toHaveBeenCalled();
      expect(updateDistribution).toHaveBeenCalledWith(expect.objectContaining({
        DistributionConfig: expect.objectContaining({
          Origins: expect.objectContaining({
            Items: [expect.objectContaining({
              Id: originIdForPrivateBucket,
              DomainName: originIdForPrivateBucket,
              OriginAccessControlId: oac.originAccessControl.Id,
              S3OriginConfig: {
                OriginAccessIdentity: ""
              }
            })]
          }),
          DefaultCacheBehavior: expect.objectContaining({
            TargetOriginId: originIdForPrivateBucket
          })
        })
      }));
    });
  });
});
